Small, artificially generated toy data set that
provides artificial information of count phenotypes and covariates for 200 individuals
to illustrate the analysis with the use of the package.
Usage
data(Ex1_phenodata)
Arguments
Format
An object of class "data.frame"
FID
Family IDs
IID
Individual IDs
count
Zero-inflated count phenotypes
educ
Covariate education years
sex
Covariate sex
PC1
The first principal component
PC2
The second principal component
PC3
The third principal component
References
This data set was artificially created and modified for the ZIM4rv package.