Learn R Programming

ZIM4rv (version 0.1.1)

Ex2_dosage: An example dataset of dosage file

Description

Small, artificially generated toy data set that provides artificial information of dosage for 15 individuals to illustrate the pre-processing with the use of the package.

Usage

data(Ex2_dosage)

Arguments

Format

An object of .dosage file

References

This data set was artificially created and modified for the ZIM4rv package.

Examples

Run this code

data(Ex2_dosage)
head(Ex2_dosage)

Run the code above in your browser using DataLab