Learn R Programming

ZIM4rv (version 0.1.1)

Ex2_fam: An example dataset of .fam file

Description

Small, artificially generated toy data set that provides artificial information of .fam file for 15 individuals to illustrate the pre-processing with the use of the package.

Usage

data(Ex2_fam)

Arguments

Format

An object of standard .fam file

References

This data set was artificially created and modified for the ZIM4rv package.

Examples

Run this code

data(Ex2_fam)
head(Ex2_fam)

Run the code above in your browser using DataLab