Learn R Programming

ZIM4rv (version 0.1.1)

Ex2_pheno: An example dataset of pheno file

Description

Small, artificially generated toy data set that provides artificial information of phenotypes for 15 individuals to illustrate the pre-processing with the use of the package.

Usage

data(Ex2_pheno)

Arguments

Format

An object of class "data.frame" listing IDs and phenotypes separately

References

This data set was artificially created and modified for the ZIM4rv package.

Examples

Run this code

data(Ex2_pheno)
head(Ex2_pheno)

Run the code above in your browser using DataLab