Ex2_region: An example dataset of genetic region file
Description
Small, artificially generated toy data set that
provides artificial information of 3 genetic regions
to illustrate the pre-processing with the use of the package.
Usage
data(Ex2_region)
Arguments
Format
An object of class "data.frame" listing genetic regions
where each row contains chromosome, basepairs and the name of genetic region respectively
References
This data set was artificially created and modified for the ZIM4rv package.