Learn R Programming

ZIM4rv (version 0.1.1)

U_phi_mu4zinb: U_phi_mu4zinb

Description

Compute score statistics for ZINB model

This function takes the estimations of phi and lambda produced by the phi_lambda_hat4negbin and computes the score statistics for ZINB model under the null hypothesis.

Usage

U_phi_mu4zinb(simudata, G_rare)

Value

a list of 2 matrice of the score statistics for each variant from each subject

Arguments

simudata

a data frame containing a phenotype named y and covariates

G_rare

a data frame containing data of rare variants with the same subject order as in simudata