Learn R Programming

ZIM4rv (version 0.1.1)

p_burden_single: p_burden_single

Description

Compute the p-value for the burden test

This function takes a vector of weights, a data frame of rare variants and a matrix of Score statistics produced by U_fi_lmd for ZIP model or U_phi_mu4zinb for ZINB model to compute the p-value for the burden test.

Usage

p_burden_single(wt, G_rare, s)

Value

the p-value for the burden test

Arguments

wt

a numeric vector containing weights for all variants

G_rare

a data frame containing data of rare variants

s

a matrix of the score statistics for each variant from each subject