Estimation of phi_hat, mu_hat and alpha_hat for ZINB model
This function gives the estimation of three parameters phi, mu and alpha in ZINB model for each subject under the null hypothesis.
phi_mu_hat4zinb(simud)a list of 3 estimations of parameters for each subject
a data frame containing a phenotype named y and covariates
This function first fits zero‐inflated negative binomial regression of phenotype y on the covariates only to obtain the estimates of regression coefficients and inverse dispersion and then compute the estimations of phi, mu and alpha.
zeroinfl