powered by
Preprocess genotype files in PLINK format
This function converts PLINK format files into data frames containing genotypes information in proper format for the model fitting and testing.
preprocess_genedata(fam_file, dosage_file, region_file, gene_name)
a data frame containing genotypes for all individuals in the required format for model fitting and testing
.fam file in PLINK format
a dosage file includes dosage information of each variant for all individuals
a file listing genetic regions where each row contains chromosome, basepairs and the name of genetic region respectively
a character string of the name of a gene, e.g."CEPT". The name is case-sensitive.
data(Ex2_fam) data(Ex2_dosage) data(Ex2_region) preprocess_genedata(Ex2_fam,Ex2_dosage,Ex2_region,"r2")
Run the code above in your browser using DataLab