Learn R Programming

ZIM4rv (version 0.1.1)

preprocess_phenodata: preprocess_phenodata

Description

Preprocess phenotype files in PLINK format

This function converts PLINK format files into data frames containing phenotypes and covariates information in proper format for the model fitting and testing.

Usage

preprocess_phenodata(pheno_file, cov_file)

Value

a data frame containing phenotypes and covariates respectively for all individuals in the required format for model fitting and testing

Arguments

pheno_file

phenotype file in PLINK format

cov_file

covariate file in PLINK format

Examples

Run this code
data(Ex2_pheno)
data(Ex2_covar)
preprocess_phenodata(Ex2_pheno,Ex2_covar)

Run the code above in your browser using DataLab