Small, artificially generated toy data set that
provides artificial information of genotypes for 200 individuals
on 3 rs locations to illustrate the analysis with the use of the package.
Usage
data(Ex1_genedata)
Arguments
Format
An object of class "data.frame"
FID
Family IDs
IID
Individual IDs
rs1
Genotype code for rs1
rs2
Genotype code for rs2
rs3
Genotype code for rs3
References
This data set was artificially created and modified for the ZIM4rv package.