Compute score statistics for ZINB model
This function takes the estimations of phi and lambda produced by the phi_lambda_hat4negbin
and computes the score statistics for ZINB model under the null hypothesis.
U_phi_mu4zinb(simudata, G_rare)a list of 2 matrice of the score statistics for each variant from each subject
a data frame containing a phenotype named y and covariates
a data frame containing data of rare variants with the same subject order as in simudata