This function converts PLINK format files into data frames containing phenotypes and covariates information in proper format
for the model fitting and testing.
Usage
preprocess_phenodata(pheno_file, cov_file)
Value
a data frame containing phenotypes and covariates respectively for all individuals in the required format for model fitting and testing